@@ -13,11 +13,11 @@ Test::Group - Group together related tests in a test suite
 
 =head1 VERSION
 
-Test::Group version 0.07
+Test::Group version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -262,10 +262,6 @@ BEGIN { die "Need Test::Simple version 0.59 or later, sorry"
 use IO::File;
 use File::Spec;
 
-our $__reversed__;  # Test groups that should fail, will succeed if
-                    # set to true, and vice versa. To be used *only*
-                    # for self-tests.
-
 my $classstate_verbose;
 my $classstate_skipcounter;
 my $classstate_skipreason;
